# LLMNT plugin for LiveKit Agents

Support for voice synthesis with [LMNT](https://app.lmnt.com/).

See [https://docs.livekit.io/agents/integrations/tts/lmnt/]https://docs.livekit.io/agents/integrations/tts/lmnt/ for more information.

## Installation

```bash
pip install livekit-plugins-lmnt
```

## Pre-requisites

You'll need an API key from LMNT. It can be set as an environment variable: `LMNT_API_KEY`. You can get it from [here](https://app.lmnt.com/account#api-keys)
